<?php

namespace app\admin\controller\order;

use app\admin\validate\coupon\CouponValidate;
use app\admin\validate\device\DeviceValidate;
use app\admin\validate\order\OrderExpressValidate;
use app\admin\validate\order\OrderValidate;
use app\controller\Curd;
use app\model\Appointment;
use app\model\Coupon;
use app\model\Device;
use app\model\Goods;
use app\model\GoodsComponent;
use app\model\Order;
use app\model\OrderExpress;
use app\model\OrderSheet;
use app\model\Supplier;
use app\model\SysSerial;
use support\Db;
use support\exception\BusinessException;
use support\Redis;
use support\Request;
use support\Response;

class WholeController extends Curd
{
    public function __construct()
    {
        $this->model = new Order();
        $this->validate = true;
        $this->validateClass = new OrderValidate();
    }

    /**
     * @Desc 列表
     * @Author Gorden
     * @Date 2024/3/28 15:01
     *
     * @param Request $request
     * @return Response
     * @throws \support\exception\BusinessException
     */
    public function select(Request $request): Response
    {
        [$where, $format, $limit, $field, $order] = $this->selectInput($request);
        if (!empty($where['order_addtimes'])) {
            $where['order_addtimes'][0] = strtotime($where['order_addtimes'][0]);
            $where['order_addtimes'][1] = strtotime($where['order_addtimes'][1]);
        }
        $order = $request->get('order', 'desc');
        $field = $field ?? 'order_addtimes';
        if (!empty($where['order_status_system']) && $where['order_status_system'] == 'RETURN') {
            unset($where['order_status_system']);
            $where['order_category'] = 'RETURN';
        }
        $query = $this->doSelect($where, $field, $order);
        return $this->doFormat($query, $format, $limit);
    }

    protected function doSelect(array $where, string $field = null, string $order = 'desc')
    {
        $model = $this->model->with([
            'sheet' => function ($query) {
                $query->select('join_sheet_order_id', 'join_sheet_goods_id');
            },
            'member' => function ($query) {
                $query->select('member_id', 'member_mobile');
            }
        ]);
        foreach ($where as $column => $value) {
            if (is_array($value)) {
                if ($value[0] === 'like' || $value[0] === 'not like') {
                    $model = $model->where($column, $value[0], "%$value[1]%");
                } elseif (in_array($value[0], ['>', '=', '<', '<>'])) {
                    $model = $model->where($column, $value[0], $value[1]);
                } elseif ($value[0] == 'in' && !empty($value[1])) {
                    $valArr = $value[1];
                    if (is_string($value[1])) {
                        $valArr = explode(",", trim($value[1]));
                    }
                    $model = $model->whereIn($column, $valArr);
                } elseif ($value[0] == 'not in' && !empty($value[1])) {
                    $valArr = $value[1];
                    if (is_string($value[1])) {
                        $valArr = explode(",", trim($value[1]));
                    }
                    $model = $model->whereNotIn($column, $valArr);
                } elseif ($value[0] == 'null') {
                    $model = $model->whereNull($column);
                } elseif ($value[0] == 'not null') {
                    $model = $model->whereNotNull($column);
                } elseif ($value[0] !== '' || $value[1] !== '') {
                    $model = $model->whereBetween($column, $value);
                }
            } else {
                $model = $model->where($column, $value);
            }
        }
        if ($field) {
            $model = $model->orderBy($field, $order);
        }
        return $model;
    }

    public function afterQuery($items)
    {
        foreach ($items as &$item) {
            if (!empty($item['sheet'])) {
                $item['sheet']['goods_name'] = Goods::where('goods_id', $item['sheet']['join_sheet_goods_id'])->value('goods_name');
            }
        }

        return $items;
    }

    /**
     * @Desc 订单商品详情
     * @Author Gorden
     * @Date 2024/3/29 8:50
     *
     * @param Request $request
     * @return Response
     */
    public function sheet(Request $request)
    {
        $orderId = $request->get('order_id');
        $orderSheet = OrderSheet::with([
            'member' => function ($query) {
                $query->select('member_id', 'member_mobile');
            },
            'goods' => function ($query) {
                $query->select('goods_id', 'goods_name', 'goods_cover', 'goods_market_price', 'goods_sales_price', 'goods_classify');
            },
            'memberInfo',
            'cert'
        ])->where('join_sheet_order_id', $orderId)
            ->get()
            ->toArray();
        foreach ($orderSheet as &$item) {
            $item['goods']['goods_cover'] = getenv('STORAGE_DOMAIN') . $item['goods']['goods_cover'];
            if (!empty($item['goods']) && $item['goods']['goods_classify'] == 'PACKAGE') {
                $components = GoodsComponent::with('goods')
                    ->where('join_component_master_goods_id', $item['goods']['goods_id'])
                    ->select('join_component_master_goods_id', 'join_component_goods_id', 'goods_component_price',
                        'goods_component_price', 'goods_component_json')
                    ->get()
                    ->toArray();
                $goodsArr = [];
                foreach ($components as $component) {
                    $configJson = !empty($component['goods_component_json']) ? json_decode($component['goods_component_json'], true) : [];
                    if (!empty($component['goods'])) {
                        $supplierName = Supplier::where('supplier_id', $component['goods']['join_goods_supplier_id'])->value('supplier_name');
                        $goodsArr[] = [
                            'goods_name' => $component['goods']['goods_name'],
                            'goods_cover' => getenv('STORAGE_DOMAIN') . $component['goods']['goods_cover'],
                            'supplier_name' => $supplierName,
                            'nbr' => $configJson['nbr'] ?? 0,
                        ];
                    }
                }

                $item['goods']['components'] = $goodsArr;
            }
        }

        $order = Order::where('order_id', $orderId)->first();
        $express = OrderExpress::where('join_express_order_id', $orderId)->first();
        $data = [
            'order' => $order,
            'sheet' => $orderSheet,
            'express' => $express
        ];

        return json_success('', $data);
    }

//    protected function updateInput(Request $request): array
//    {
//        $primary_key = $this->model->getKeyName();
//        $id = $request->post($primary_key);
//        $data = $this->inputFilter($request->post());
//        $data['coupon_begindate'] = strtotime($data['coupon_begindate']);
//        $data['coupon_enddate'] = strtotime($data['coupon_enddate']);
//        $model = $this->model->find($id);
//        if (!$model) {
//            throw new BusinessException('记录不存在', 2);
//        }
//        unset($data[$primary_key]);
//        return [$id, $data];
//    }

    public function delivery(Request $request)
    {
        if (!Order::where('order_id', $request->post('order_id'))->where('order_status_system', 'SENDING')->exists()) {
            return json_fail('订单状态异常');
        }

        // 验证
        $validate = new OrderExpressValidate();
        if (!$validate->scene('delivery')->check($request->post())) {
            return json_fail($validate->getError());
        }
        try {
            Db::beginTransaction();
            // 该订单状态
            Order::where('order_id', $request->post('order_id'))->update(['order_status_system' => 'RECVING', 'order_status_storage' => 'EXPRESSING']);
            // 订单包含的产品
            $sheet = OrderSheet::where('join_sheet_order_id', $request->post('order_id'))
                ->select('join_sheet_goods_id')
                ->get();
            // 入配送记录表
            $params = $request->post();
            $model = new OrderExpress();
            $model->join_express_order_id = $params['order_id'];
            $model->order_express_goods = $sheet;
            $model->order_express_type = $params['order_express_type'];
            $model->order_express_code = $params['order_express_code'];
            $model->order_express_city = implode("-", $params['order_express_city']);
            $model->order_express_address = $params['order_express_address'];
            $model->order_express_mobile = $params['order_express_mobile'];
            $model->order_express_telephone = $params['order_express_telephone'] ?? null;
            $model->order_express_person = $params['order_express_person'] ?? null;
            $model->order_express_remark = $params['order_express_remark'] ?? null;
            $model->order_express_addtimes = time();
            $model->save();

            // 15天后自动确认收货
            $redis = Redis::connection();
            $key = Order::AUTOMATIC_RECEIPT_PREFIX . date('Ymd', strtotime("+15 days"));
            $redis->sadd($key, $params['order_id']);

            Db::commit();

            return json_success('发货成功');
        } catch (\Exception $e) {
            Db::rollBack();

            return json_fail('发货失败');
        }
    }

    public function myOrder(Request $request)
    {
        $memberId = $request->get('member_id', '');
        if (!$memberId) {
            return json_fail('查询错误');
        }

        $sheet = OrderSheet::with([
            'goods' => function ($query) {
                $query->select('goods_id', 'goods_name', 'goods_cover');
            },
            'order' => function ($query) {
                $query->select('order_id', 'order_status_system', 'order_status_payment', 'order_status_storage');
            }
        ])->where('join_sheet_member_id', $memberId)
            ->orderBy('order_sheet_addtimes', 'desc')
            ->get()
            ->toArray();
        foreach ($sheet as &$item) {
            if (!empty($item->goods->goods_cover)) {
                $item->goods->goods_cover = getenv('STORAGE_DOMAIN') . $item->goods->goods_cover;
            }
        }

        // 预约单
        $appointments = Db::table('appointment')
//            ->leftJoin('member', 'member.member_id', '=', 'appointment.join_appointment_member_id')
//            ->leftJoin('member_cert', 'member_cert.join_cert_member_id', '=', 'appointment.join_appointment_member_id')
//            ->leftJoin('member_info', 'member_info.join_info_member_id', '=', 'appointment.join_appointment_member_id')
            ->leftJoin('goods', 'goods.goods_id', '=', 'appointment.join_appointment_goods_id')
//            ->leftJoin('order', 'order.order_id', '=', 'appointment.join_appointment_order_id')
            ->leftJoin('member_benefit', 'member_benefit.member_benefit_id', '=', 'appointment.join_appointment_member_benefit_id')
//            ->leftJoin('goods_sku', 'goods_sku.goods_sku_id', '=', 'appointment.join_appointment_goods_sku_id')
            ->where('join_appointment_member_id', $memberId)
            ->select('appointment.*',
//            'member.member_mobile',
//            'member_cert.member_cert_name',
//            'member_info.member_info_nickname',
                'goods.goods_name', 'goods.goods_sales_price',
//            'order.order_name', 'goods_sku.goods_sku_specs_json', 'order.order_amount_total', 'order.order_amount_pay',
//            'order.order_category', 'order.order_status_system', 'order.order_status_payment', 'order.order_status_storage',
//            'order.order_addtimes',
                'member_benefit.member_benefit_name'
            )
            ->orderBy('appointment.appointment_addtimes', 'desc')
            ->get();
        foreach ($appointments as &$row) {
            if ($row->appointment_category == 'NOFEE') {
                $row->member_benefit_name = "后付费预约";
            }
            $row->appointment_addtimes = date('Y-m-d H:i:s', $row->appointment_addtimes);
        }

        return json_success('', ['order' => $sheet, 'appointment' => $appointments]);
    }

    // TODO 确认收货（完成订单）
    public function confirm($id)
    {
        $order = Order::where('order_id', $id)->first();
        if (empty($order)) {
            return json_fail("暂无数据");
        }

        Db::beginTransaction();
        try {
            // 主订单
            Order::where('order_id', $id)->update(['order_status_system' => 'CONFIRM']);
        } catch (\Exception $e) {

        }
    }
}