<?php

namespace app\admin\controller\sys_manage;

use app\admin\service\sys_manage\DeptService;
use app\admin\validate\sys_manage\DeptValidate;
use support\Request;

class DeptController
{
    /**
     * @Desc 部门列表
     * @Author Gorden
     * @Date 2024/2/21 10:29
     *
     * @param Request $request
     * @return \support\Response
     */
    public function deptList(Request $request)
    {
        $page = $request->get('page', 1);
        $limit = $request->get('limit', 10);
        $keywords = format_string($request->get('keywords', ''));

        return DeptService::deptList($page, $limit, $keywords);
    }

    public function selectList(Request $request)
    {
        return DeptService::selectList($request);
    }

    /**
     * @Desc 部门详情
     * @Author Gorden
     * @Date 2024/2/21 10:35
     *
     * @param $id
     * @return \support\Response
     */
    public function deptInfo($id)
    {
        return DeptService::deptInfo($id);
    }

    /**
     * @Desc 创建部门
     * @Author Gorden
     * @Date 2024/2/21 9:22
     *
     * @param Request $request
     * @return \support\Response
     */
    public function addDept(Request $request)
    {
        $validate = new DeptValidate();
        if (!$validate->scene('add')->check($request->post())) {
            return json_fail($validate->getError());
        }

        return DeptService::insertDept($request->post());
    }

    /**
     * @Desc 修改部门
     * @Author Gorden
     * @Date 2024/2/21 10:15
     *
     * @param $id
     * @param Request $request
     * @return \support\Response
     */
    public function updateDept($id, Request $request)
    {
        $validate = new DeptValidate();
        if (!$validate->scene('update')->check($request->post())) {
            return json_fail($validate->getError());
        }

        return DeptService::updateDept($id, $request->post());
    }

    /**
     * @Desc 修改部门状态
     * @Author Gorden
     * @Date 2024/2/21 10:41
     *
     * @param $id
     * @param $status
     * @return \support\Response
     */
    public function updateStatus($id, Request $request)
    {
        $validate = new DeptValidate();
        if (!$validate->scene('update_status')->check($request->post())) {
            return json_fail($validate->getError());
        }

        return DeptService::updateStatus($id, $request->post('dept_status'));
    }

    public function delDept($id)
    {
        return DeptService::delDept($id);
    }
}