<?php

namespace app\admin\service\order;

use app\model\Appointment;
use app\model\Goods;
use app\model\Member;
use app\model\MemberAccount;
use app\model\MemberBenefit;
use app\model\MemberCert;
use app\model\MemberInfo;
use app\model\Order;
use app\model\OrderSheet;
use app\model\PayDetail;
use app\model\SysSerial;
use support\Db;
use support\Request;
use function _PHPStan_cc8d35ffb\RingCentral\Psr7\str;

class AppointmentService
{
    public static function select(Request $request)
    {
        $page = $request->get('page');
        $pageSize = $request->get('pageSize');
        $id = $request->get('id', '');
        $mobile = $request->get('mobile', '');
        $status = $request->get('status', '');

        $rows = Db::table('appointment')
            ->leftJoin('member', 'member.member_id', '=', 'appointment.join_appointment_member_id')
            ->leftJoin('member_cert', 'member_cert.join_cert_member_id', '=', 'appointment.join_appointment_member_id')
            ->leftJoin('member_info', 'member_info.join_info_member_id', '=', 'appointment.join_appointment_member_id')
            ->leftJoin('goods', 'goods.goods_id', '=', 'appointment.join_appointment_goods_id')
            ->leftJoin('order', 'order.order_id', '=', 'appointment.join_appointment_order_id')
            ->leftJoin('member_benefit', 'member_benefit.member_benefit_id', '=', 'appointment.join_appointment_member_benefit_id')
            ->leftJoin('goods_sku', 'goods_sku.goods_sku_id', '=', 'appointment.join_appointment_goods_sku_id')
            ->when($id != '', function ($query) use ($id) {
                $query->where('appointment.appointment_id', 'like', '%' . $id . '%');
            })->when($mobile != '', function ($query) use ($mobile) {
                $query->where('member.member_mobile', 'like', '%' . $mobile . '%');
            })->when($status != '', function ($query) use ($status) {
                $query->where('appointment.appointment_status', $status);
            });

        $total = $rows->count('member.member_id');
        $rows = $rows->select('appointment.*',
            'member.member_mobile',
            'member_cert.member_cert_name',
            'member_info.member_info_nickname',
            'goods.goods_name', 'goods.goods_cover', 'goods.goods_sales_price',
            'order.order_name', 'goods_sku.goods_sku_specs_json', 'order.order_amount_total', 'order.order_amount_pay',
            'order.order_category', 'order.order_status_system', 'order.order_status_payment', 'order.order_status_storage',
            'order.order_addtimes',
            'member_benefit.member_benefit_name'
        )
            ->orderBy('appointment.appointment_addtimes', 'desc')
            ->forPage($page, $pageSize)
            ->get();

        foreach ($rows as &$row) {
            $row->goods_cover = getenv('STORAGE_DOMAIN') . $row->goods_cover;
            $row->goods_sku_specs_json = !empty($row->goods_sku_specs_json) ? json_decode($row->goods_sku_specs_json, true) : [];
            $row->order_addtimes = date('Y-m-d H:i:s', $row->order_addtimes);
            $row->appointment_addtimes = date('Y-m-d H:i:s', $row->appointment_addtimes);
            $row->appointment_apply_json = !empty($row->appointment_apply_json) ? json_decode($row->appointment_apply_json,true) : [];
            if ($row->appointment_category == 'NOFEE') {
                $row->member_benefit_name = "后付费预约";
            }
            if (!empty($row->appointment_apply_json)) {
                $applyJson = $row->appointment_apply_json;
                $row->person = $applyJson['person'] ?? '';
                $row->appointment_times = $applyJson['times'] ?? '';
            }
        }
        return json_success('', compact('rows', 'page', 'pageSize', 'total'));
    }

    public static function confirm($id)
    {
        $appointment = Appointment::where('appointment_id', $id)->where('appointment_status', 'WAITING')->first();
        if (!$appointment) {
            return json_fail('数据异常');
        }

        try {
            $appointment->appointment_status = 'PENDING';
            $appointment->save();

            return json_success('操作成功');
        } catch (\Exception $e) {
            dump($e->getMessage());
            return json_fail("操作失败");
        }
    }

    public static function add(Request $request)
    {
        $params = $request->post();
        Db::beginTransaction();
        try {
            // 先检查选择的时段是否可预约
            $goods = Goods::where('goods_id', $params['join_appointment_goods_id'])->first();
            $appointments = Appointment::where('appointment_datetime', $params['appointment_datetime'])->get()->toArray();
            if ($goods->is_support_appointment == 'Y' && !empty($goods->goods_attribute_json)) {
                $extendJson = json_decode($goods->goods_attribute_json, true);
                foreach ($extendJson['times'] as $key => $time) {
                    if ($time['duration'] == $params['appointment_times']) {
                        if (!empty($appointments)){
                            foreach ($appointments as $appointment) {
                                $applyJson = json_decode($appointment['appointment_apply_json'], true);
                                $applyJsonTimes = $applyJson['times'] ?? '';

                                if ($time['duration'] == $applyJsonTimes) {
                                    $extendJson['times'][$key]['person'] -= $applyJson['person'];
                                    if ($extendJson['times'][$key]['person'] < $params['person']) {
                                        return json_fail('当前时段名额不足，请选择其他时段');
                                    }
                                }
                            }
                        }else{
                            if ($extendJson['times'][$key]['person'] < $params['person']) {
                                return json_fail('当前时段名额不足，请选择其他时段');
                            }
                        }
                    }
                }
            }
            // 如果没有，新建
            if (empty($params['join_appointment_member_id']) && !empty($params['username']) && !empty($params['mobile'])) {
                $memberId = "ME" . str_pad(SysSerial::getSerial(), 16, "0", STR_PAD_LEFT) . random_string(6, 'up');
                $params['join_appointment_member_id'] = $memberId;

                // 主表
                $memberData = [
                    'member_id' => $memberId,
                    'member_is_owner' => 'N',
                    'member_classify' => 'MEMBER',
                    'member_status' => 'ACTIVED',
                    'member_mobile' => $params['mobile'],
                    'member_from' => 'backstage',
                    'member_addtimes' => time()
                ];
                Member::insert($memberData);
                // 账户表
                $accountData = [
                    'join_account_member_id' => $memberId,
                    'member_account_classify' => 'POINTS',
                    'member_account_status' => 'ACTIVED',
                    'member_account_category' => 'NORMAL',
                    'member_account_nbr' => $memberId . '-POINTS',
                    'member_account_name' => '积分账户',
                    'member_account_addtimes' => time()
                ];
                // 积分账户
                MemberAccount::insert($accountData);
                $accountData['member_account_classify'] = 'CASH';
                $accountData['member_account_nbr'] = $memberId . '-CASH';
                $accountData['member_account_name'] = '余额账户';
                // 现金/余额账户
                MemberAccount::insert($accountData);
                // cert
                $certData = [
                    'join_cert_member_id' => $memberId,
                    'member_cert_name' => $params['username']
                ];
                MemberCert::insert($certData);
                // info
                $infoData = [
                    'join_info_member_id' => $memberId,
                    'member_info_nickname' => $params['username']
                ];
                MemberInfo::insert($infoData);
            }
            $data = [
                'appointment_id' => "AP" . str_pad(SysSerial::getSerial(), 16, '0') . random_string(6, 'up'),
                'join_appointment_member_id' => $params['join_appointment_member_id'] ?? '',
                'join_appointment_goods_id' => $params['join_appointment_goods_id'] ?? '',
                'appointment_status' => $params['appointment_status'] ?? '',
                'appointment_datetime' => isset($params['appointment_datetime']) ? date('Y-m-d', strtotime($params['appointment_datetime'])) : '',
                'appointment_apply_datetime' => isset($params['appointment_apply_datetime']) ? date('Y-m-d H:i:s', strtotime($params['appointment_apply_datetime'])) : '',
                'appointment_doing_datetime' => isset($params['appointment_doing_datetime']) ? date('Y-m-d H:i:s', strtotime($params['appointment_doing_datetime'])) : '',
                'appointment_done_datetime' => isset($params['appointment_done_datetime']) ? date('Y-m-d H:i:s', strtotime($params['appointment_done_datetime'])) : '',
                'appointment_cancel_datetime' => isset($params['appointment_cancel_datetime']) ? date('Y-m-d H:i:s', strtotime($params['appointment_cancel_datetime'])) : '',
                'appointment_remark' => $params['appointment_remark'] ?? '',
                'appointment_category' => 'NOFEE',
                'appointment_addtimes' => time(),
                'appointment_mode' => $params['appointment_mode'] ?? '',
                'settlement_mode' => $params['settlement_mode'] ?? '',
            ];

            if (!empty($params['join_appointment_member_id'])) {
                $member = Member::with([
                    'cert' => function ($query) {
                        $query->select('join_cert_member_id', 'member_cert_name');
                    }
                ])->where('member_id', $params['join_appointment_member_id'])
                    ->first()
                    ->toArray();
                $data['appointment_apply_json'] = json_encode([
                    'name' => !empty($member['cert']['member_cert_name']) ? $member['cert']['member_cert_name'] : $member['member_mobile'],
                    'mobile' => $member['member_mobile'],
                    'person' => $params['person'],
                    'remark' => $data['appointment_remark'],
                    'premises' => $params['premises'],
                    'times' => $params['appointment_times']
                ]);
            }

            Appointment::insert($data);

            // 如果预约成功，生成订单
            if ($params['appointment_status'] == 'PENDING') {
                $orderId = 'OD' . date('YmdHis') . random_string(6, 'up');
                $order = [
                    'order_id' => $orderId,
                    'join_order_member_id' => $params['join_appointment_member_id'],
                    'order_name' => "预约-" . $goods->goods_name,
                    'order_amount_total' => $goods->goods_sales_price * $params['person'],
                    'order_amount_pay' => $goods->goods_sales_price * $params['person'],
                    'order_is_complete' => 'N',
                    'order_category' => 'OTHER',
                    'order_status_system' => 'PAYING',
                    'order_status_payment' => 'PENDING',
                    'order_status_storage' => 'PENDING',
                    'order_addtimes' => time()
                ];
                Order::insert($order);
                // 订单详情
                $sheet = [
                    'join_sheet_member_id' => $params['join_appointment_member_id'],
                    'join_sheet_order_id' => $orderId,
                    'join_sheet_goods_id' => $params['join_appointment_goods_id'],
                    'order_sheet_status' => 'PAYING',
                    'order_sheet_category' => 'APPOINTMENT',
                    'order_sheet_unit' => '套',
                    'order_sheet_num' => $params['person'],
                    'order_sheet_price' => $goods->goods_sales_price,
                    'order_sheet_amount' => $goods->goods_sales_price * $params['person'],
                    'order_sheet_pay' => $goods->goods_sales_price * $params['person'],
                    'order_sheet_task_status' => 'NONE',
                    'order_sheet_addtimes' => time()
                ];
                OrderSheet::insert($sheet);
                // 订单号更新到预约
                Appointment::where('appointment_id', $data['appointment_id'])->update(['join_appointment_order_id' => $orderId]);
                // 支付数据
                $pay = [
                    'join_pay_member_id' => $params['join_appointment_member_id'],
                    'join_pay_order_id' => $orderId,
                    'pay_amount' => $sheet['order_sheet_pay'],
                    'pay_remark' => '预约单',
                    'pay_addtimes' => time(),
                    'pay_prepayid' => 0,
                    'pay_paytimes' => date('Y-m-d H:i:s')
                ];
                // 现金余额结算
                if ($params['settlement_mode'] == 'CASH') {
                    $account = MemberAccount::where('join_account_member_id', $params['join_appointment_member_id'])
                        ->where('member_account_classify', 'CASH')
                        ->where('member_account_status', 'ACTIVED')
                        ->first();
                    if (!$account) {
                        Db::rollBack();
                        return json_fail('当前账户不存在或已过期');
                    }

                    if ($account->member_account_surplus < $sheet['order_sheet_pay']) {
                        $pay['pay_status'] = 'PENDING';
                    } else {
                        MemberAccount::where('member_account_id', $account->member_account_id)->update([
                            'member_account_expend' => $account->member_account_expend + $sheet['order_sheet_pay'],
                            'member_account_surplus' => $account->member_account_surplus - $sheet['order_sheet_pay']
                        ]);
                        $pay['pay_status'] = 'SUCCESS';
                        $pay['join_pay_object_json'] = json_encode(['payment' => ['member_account_id' => $account->member_account_id]]);
                        // 更新订单状态
                        Order::where('order_id', $orderId)->update(['order_status_system' => 'CONFIRM', 'order_status_payment' => 'SUCCESS']);
                        OrderSheet::where('join_sheet_order_id', $orderId)->update(['order_sheet_status' => 'CONFIRM']);
                    }
                    $pay['pay_category'] = 'CASH';
                    PayDetail::insert($pay);
                } elseif ($params['settlement_mode'] == 'QRCODE') {
                    $pay['pay_category'] = 'QRCODE';
                    $pay['pay_status'] = 'SUCCESS';
                    PayDetail::insert($pay);
                    // 更新订单状态
                    Order::where('order_id', $orderId)->update(['order_status_system' => 'CONFIRM', 'order_status_payment' => 'SUCCESS']);
                    OrderSheet::where('join_sheet_order_id', $orderId)->update(['order_sheet_status' => 'CONFIRM']);
                }
            }

            Db::commit();
            return json_success("添加预约成功");
        } catch (\Exception $e) {
            Db::rollBack();
            dump($e->getMessage());
            return json_fail("添加预约失败");
        }
    }


    public static function update(Request $request)
    {
        $params = $request->post();
        $appointmentId = $params['appointment_id'];
        $appointment = Appointment::where('appointment_id', $appointmentId)->first();
        if (empty($appointment)) {
            return json_fail("数据不存在");
        }
        Db::beginTransaction();
        try {
            // 先检查选择的时段是否可预约
            $goods = Goods::where('goods_id', $params['join_appointment_goods_id'])->first();
            $appointments = Appointment::where('appointment_datetime', $params['appointment_datetime'])
                ->where('appointment_id', '<>', $params['appointment_id'])
                ->get()
                ->toArray();
            if ($goods->is_support_appointment == 'Y' && !empty($goods->goods_attribute_json)) {
                $extendJson = json_decode($goods->goods_attribute_json, true);
                foreach ($extendJson['times'] as $key => $time) {
                    if ($time['duration'] == $params['appointment_times']) {
                        if (!empty($appointments)){
                            foreach ($appointments as $appointment) {
                                $applyJson = json_decode($appointment['appointment_apply_json'], true);
                                $applyJsonTimes = $applyJson['times'] ?? '';

                                if ($time['duration'] == $applyJsonTimes) {
                                    $extendJson['times'][$key]['person'] -= $applyJson['person'];
                                    if ($extendJson['times'][$key]['person'] < $params['person']) {
                                        return json_fail('当前时段名额不足，请选择其他时段');
                                    }
                                }
                            }
                        }else{
                            if ($extendJson['times'][$key]['person'] < $params['person']) {
                                return json_fail('当前时段名额不足，请选择其他时段');
                            }
                        }
                    }
                }
            }
            $data = [
                'appointment_status' => $params['appointment_status'],
                'appointment_datetime' => $params['appointment_datetime'] ? date('Y-m-d', strtotime($params['appointment_datetime'])) : null,
                'appointment_apply_datetime' => $params['appointment_apply_datetime'] ? date('Y-m-d H:i:s', strtotime($params['appointment_apply_datetime'])) : null,
                'appointment_doing_datetime' => $params['appointment_doing_datetime'] ? date('Y-m-d H:i:s', strtotime($params['appointment_doing_datetime'])) : null,
                'appointment_done_datetime' => $params['appointment_done_datetime'] ? date('Y-m-d H:i:s', strtotime($params['appointment_done_datetime'])) : null,
                'appointment_cancel_datetime' => $params['appointment_cancel_datetime'] ? date('Y-m-d H:i:s', strtotime($params['appointment_cancel_datetime'])) : null,
                'appointment_remark' => $params['appointment_remark'] ?? '',
                'appointment_mode' => $params['appointment_mode'] ?? '',
                'settlement_mode' => $params['settlement_mode'] ?? '',
            ];
            // 如果是完成状态
            if ($params['appointment_status'] == 'DONE' && $appointment->appointment_status != 'DONE') {
                if (empty($params['appointment_done_datetime'])) {
                    $data['appointment_done_datetime'] = date('Y-m-d H:i:s');
                }
                MemberBenefit::where('member_benefit_id', $appointment->join_appointment_member_benefit_id)->increment('member_benefit_used_count');
            }
            if (!empty($params['join_appointment_member_id'])) {
                $member = Member::with([
                    'cert' => function ($query) {
                        $query->select('join_cert_member_id', 'member_cert_name');
                    }
                ])->where('member_id', $params['join_appointment_member_id'])
                    ->first()
                    ->toArray();
                $data['appointment_apply_json'] = json_encode([
                    'name' => !empty($member['cert']['member_cert_name']) ? $member['cert']['member_cert_name'] : $member['member_mobile'],
                    'mobile' => $member['member_mobile'],
                    'person' => $params['person'],
                    'remark' => $data['appointment_remark'],
                    'premises' => $params['premises'],
                    'times' => $params['appointment_times']
                ]);
            }

            Appointment::where('appointment_id', $appointmentId)->update($data);

            // 如果预约成功,没有生成过订单，生成订单
            if ($params['appointment_status'] == 'PENDING' && empty($appointment->join_appointment_order_id)) {
                $orderId = 'OD' . date('YmdHis') . random_string(6, 'up');
                $order = [
                    'order_id' => $orderId,
                    'join_order_member_id' => $params['join_appointment_member_id'],
                    'order_name' => "预约-" . $goods->goods_name,
                    'order_amount_total' => $goods->goods_sales_price * $params['person'],
                    'order_amount_pay' => $goods->goods_sales_price * $params['person'],
                    'order_is_complete' => 'N',
                    'order_category' => 'OTHER',
                    'order_status_system' => 'PAYING',
                    'order_status_payment' => 'PENDING',
                    'order_status_storage' => 'PENDING',
                    'order_addtimes' => time()
                ];
                Order::insert($order);
                // 订单详情
                $sheet = [
                    'join_sheet_member_id' => $params['join_appointment_member_id'],
                    'join_sheet_order_id' => $orderId,
                    'join_sheet_goods_id' => $params['join_appointment_goods_id'],
                    'order_sheet_status' => 'PAYING',
                    'order_sheet_category' => 'APPOINTMENT',
                    'order_sheet_unit' => '套',
                    'order_sheet_num' => $params['person'],
                    'order_sheet_price' => $goods->goods_sales_price,
                    'order_sheet_amount' => $goods->goods_sales_price * $params['person'],
                    'order_sheet_pay' => $goods->goods_sales_price * $params['person'],
                    'order_sheet_task_status' => 'NONE',
                    'order_sheet_addtimes' => time()
                ];
                OrderSheet::insert($sheet);
                // 订单号更新到预约
                Appointment::where('appointment_id', $appointmentId)->update(['join_appointment_order_id' => $orderId]);

                // 支付数据
                $pay = [
                    'join_pay_member_id' => $params['join_appointment_member_id'],
                    'join_pay_order_id' => $orderId,
                    'pay_amount' => $sheet['order_sheet_pay'],
                    'pay_remark' => '预约单',
                    'pay_addtimes' => time(),
                    'pay_prepayid' => 0,
                    'pay_paytimes' => date('Y-m-d H:i:s')
                ];
                // 现金余额结算
                if ($params['settlement_mode'] == 'CASH') {
                    $account = MemberAccount::where('join_account_member_id', $params['join_appointment_member_id'])
                        ->where('member_account_classify', 'CASH')
                        ->where('member_account_status', 'ACTIVED')
                        ->first();
                    if (!$account) {
                        Db::rollBack();
                        return json_fail('当前账户不存在或已过期');
                    }

                    if ($account->member_account_surplus < $sheet['order_sheet_pay']) {
                        $pay['pay_status'] = 'PENDING';
                    } else {
                        MemberAccount::where('member_account_id', $account->member_account_id)->update([
                            'member_account_expend' => $account->member_account_expend + $sheet['order_sheet_pay'],
                            'member_account_surplus' => $account->member_account_surplus - $sheet['order_sheet_pay']
                        ]);
                        $pay['pay_status'] = 'SUCCESS';
                        $pay['join_pay_object_json'] = json_encode(['payment' => ['member_account_id' => $account->member_account_id]]);
                        // 更新订单状态
                        Order::where('order_id', $orderId)->update(['order_status_system' => 'CONFIRM', 'order_status_payment' => 'SUCCESS']);
                        OrderSheet::where('join_sheet_order_id', $orderId)->update(['order_sheet_status' => 'CONFIRM']);
                    }
                    $pay['pay_category'] = 'CASH';
                    PayDetail::insert($pay);
                } elseif ($params['settlement_mode'] == 'QRCODE' && empty($appointment->join_appointment_order_id)) {
                    $pay['pay_category'] = 'QRCODE';
                    $pay['pay_status'] = 'SUCCESS';
                    PayDetail::insert($pay);
                    // 更新订单状态
                    Order::where('order_id', $orderId)->update(['order_status_system' => 'CONFIRM', 'order_status_payment' => 'SUCCESS']);
                    OrderSheet::where('join_sheet_order_id', $orderId)->update(['order_sheet_status' => 'CONFIRM']);
                }
            }

            Db::commit();
            return json_success("数据更新成功");
        } catch (\Exception $e) {
            Db::rollBack();
            dump($e->getTrace());
            return json_fail("数据更新失败");
        }
    }

    public static function getTimes(Request $request)
    {
        $goodsId = $request->get('goods_id', '');
        $date = $request->get('date', '');
//        $memberId = $request->get('member_id', '');
        $appointmentId = $request->get('appointment_id', '');
        if (!$goodsId || !$date) {
            return json_fail("查询时间段失败！");
        }

        $goods = Goods::where('goods_id', $goodsId)->first();
        if (!$goods) {
            return json_fail('数据不存在');
        }

        // 当前服务已预约出去的
        $appointments = Appointment::where('join_appointment_goods_id', $goodsId)
            ->where('appointment_datetime', $date)
            ->when($appointmentId != '', function ($query) use ($appointmentId) {
                $query->where('appointment_id', '<>', $appointmentId);
            })
            ->get()
            ->toArray();
        if ($goods->is_support_appointment == 'Y' && !empty($goods->goods_attribute_json)) {
            $extendJson = json_decode($goods->goods_attribute_json, true);
            $times = $extendJson['times'];
            foreach ($times as $key => $time) {
//                $timesStr = $time['appointmentTimeStart'] . '~' . $time['appointmentTimeEnd'];
                $times[$key]['timesStr'] = $time['duration'];
                foreach ($appointments as $appointment) {
                    if (!empty($appointment['appointment_apply_json'])) {
                        $applyJson = json_decode($appointment['appointment_apply_json'], true);
                        $applyJsonTimes = $applyJson['times'] ?? '';
                        if ($time['duration'] == $applyJsonTimes) {
                            $times[$key]['person'] -= $applyJson['person'];
                            if ($times[$key]['person'] < 1) {
                                $times[$key]['disabled'] = true;
                            }
                        }
                    }
                }
            }
            return json_success('', $times);
        }
    }
}