<?php

use Webman\Route;

Route::group('/admin', function () {
    Route::group('/upload', function () {
        Route::post('/image', [\app\admin\controller\sys_manage\UploadController::class, 'image']);
        Route::post('/video', [\app\admin\controller\sys_manage\UploadController::class, 'video']);
        Route::post('/file', [\app\admin\controller\sys_manage\UploadController::class, 'file']);
        Route::post('/updateStatus/{id:\d+}', [\app\admin\controller\sys_manage\UploadController::class, 'updateStatus']);
    })->middleware([
        \app\middleware\AdminAuthCheck::class
    ]);
    /* 鉴权 */
    Route::group('/auth', function () {
        Route::post('/login', [\app\admin\controller\auth\AuthController::class, 'login']);
        Route::get('/userInfo', [\app\admin\controller\auth\AuthController::class, 'userInfo']);
        Route::get('/refreshToken', [\app\admin\controller\auth\AuthController::class, 'refreshToken']);
    })->middleware([
        \app\middleware\AdminAuthCheck::class
    ]);
    Route::group('/content',function (){
        Route::group('/special',function (){
            Route::get('/list', [\app\admin\controller\content\SpecialController::class, 'select']);
            Route::post('/add', [\app\admin\controller\content\SpecialController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\content\SpecialController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\content\SpecialController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
    });
    Route::group('/goods', function () {
        /* 实物商品管理 */
        Route::group('/entity', function () {
            Route::get('/selectAll', [\app\admin\controller\goods\EntityGoodsController::class, 'selectAll']);
            Route::get('/list', [\app\admin\controller\goods\EntityGoodsController::class, 'select']);
            Route::get('/info', [\app\admin\controller\goods\EntityGoodsController::class, 'info']);
            Route::post('/add', [\app\admin\controller\goods\EntityGoodsController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\goods\EntityGoodsController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\goods\EntityGoodsController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        /* 业务服务商品管理 */
        Route::group('/service', function () {
            Route::get('/list', [\app\admin\controller\goods\ServiceGoodsController::class, 'select']);
            Route::get('/selectList', [\app\admin\controller\goods\ServiceGoodsController::class, 'selectList']);
            Route::get('/selectPicking', [\app\admin\controller\goods\ServiceGoodsController::class, 'selectPicking']);
            Route::get('/info', [\app\admin\controller\goods\ServiceGoodsController::class, 'info']);
            Route::post('/add', [\app\admin\controller\goods\ServiceGoodsController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\goods\ServiceGoodsController::class, 'update']);
            Route::post('/changeStatus', [\app\admin\controller\goods\ServiceGoodsController::class, 'changeStatus']);
            Route::delete('/delete', [\app\admin\controller\goods\ServiceGoodsController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        /* 营销专题商品管理 */
        Route::group('/special', function () {
            Route::get('/list', [\app\admin\controller\goods\SpecialGoodsController::class, 'select']);
            Route::get('/info', [\app\admin\controller\goods\SpecialGoodsController::class, 'info']);
            Route::post('/add', [\app\admin\controller\goods\SpecialGoodsController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\goods\SpecialGoodsController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\goods\SpecialGoodsController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        /*套包商品管理 */
        Route::group('/package', function () {
            Route::get('/list', [\app\admin\controller\goods\PackageGoodsController::class, 'select']);
            Route::get('/selectList', [\app\admin\controller\goods\PackageGoodsController::class, 'selectList']);
            Route::get('/info', [\app\admin\controller\goods\PackageGoodsController::class, 'info']);
            Route::post('/add', [\app\admin\controller\goods\PackageGoodsController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\goods\PackageGoodsController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\goods\PackageGoodsController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
    });
    /* 系统管理中心 */
    Route::group('/sys', function () {
        /* API管理 */
        Route::group('/api', function () {
            Route::get('/list', [\app\admin\controller\sys_manage\ApiController::class, 'select']);
            Route::post('/add', [\app\admin\controller\sys_manage\ApiController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\sys_manage\ApiController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\sys_manage\ApiController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        /* 角色管理 */
        Route::group('/role', function () {
            Route::get('/select', [\app\admin\controller\sys_manage\RoleController::class, 'select']);
            Route::get('/list', [\app\admin\controller\sys_manage\RoleController::class, 'roleList']);
            Route::get('/info/{id:\d+}', [\app\admin\controller\sys_manage\RoleController::class, 'roleInfo']);
            Route::post('/add', [\app\admin\controller\sys_manage\RoleController::class, 'addRole']);
            Route::post('/update/{id:\d+}', [\app\admin\controller\sys_manage\RoleController::class, 'updateRole']);
            Route::delete('/delete', [\app\admin\controller\sys_manage\RoleController::class, 'delRole']);
            Route::post('/updateStatus/{id:\d+}', [\app\admin\controller\sys_manage\RoleController::class, 'updateStatus']);
            Route::post('/updatePermission/{id:\d+}', [\app\admin\controller\sys_manage\RoleController::class, 'updatePermission']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        /* 部门管理 */
        Route::group('/dept', function () {
            Route::get('/list', [\app\admin\controller\sys_manage\DeptController::class, 'deptList']);
            Route::get('/selectList', [\app\admin\controller\sys_manage\DeptController::class, 'selectList']);
            Route::get('/info/{id:\d+}', [\app\admin\controller\sys_manage\DeptController::class, 'deptInfo']);
            Route::post('/add', [\app\admin\controller\sys_manage\DeptController::class, 'addDept']);
            Route::post('/update/{id:\d+}', [\app\admin\controller\sys_manage\DeptController::class, 'updateDept']);
            Route::post('/updateStatus/{id:\d+}', [\app\admin\controller\sys_manage\DeptController::class, 'updateStatus']);
            Route::delete('/delete/{id:\d+}', [\app\admin\controller\sys_manage\DeptController::class, 'delDept']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        /* 用户管理 */
        Route::group('/user', function () {
            Route::get('/list', [\app\admin\controller\sys_manage\UserController::class, 'userList']);
            Route::get('/info/{id:\w+}', [\app\admin\controller\sys_manage\UserController::class, 'userInfo']);
            Route::post('/add', [\app\admin\controller\sys_manage\UserController::class, 'addUser']);
            Route::post('/update/{id:\w+}', [\app\admin\controller\sys_manage\UserController::class, 'updateUser']);
            Route::post('/updateStatus/{id:\w+}', [\app\admin\controller\sys_manage\UserController::class, 'updateStatus']);
            Route::post('/updatePassword/{id:\w+}', [\app\admin\controller\sys_manage\UserController::class, 'updatePassword']);
            Route::delete('/delete', [\app\admin\controller\sys_manage\UserController::class, 'delUser']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        /* 分类管理 */
        Route::group('/category', function () {
            Route::get('/index', [\app\admin\controller\sys_manage\CategoryController::class, 'index']);
            Route::get('/list', [\app\admin\controller\sys_manage\CategoryController::class, 'categoryList']);
            Route::get('/info/{id:\d+}', [\app\admin\controller\sys_manage\CategoryController::class, 'categoryInfo']);
            Route::post('/add', [\app\admin\controller\sys_manage\CategoryController::class, 'addCategory']);
            Route::post('/update/{id:\d+}', [\app\admin\controller\sys_manage\CategoryController::class, 'updateCategory']);
            Route::post('/updateStatus/{id:\d+}', [\app\admin\controller\sys_manage\CategoryController::class, 'updateStatus']);
            Route::delete('/delete', [\app\admin\controller\sys_manage\CategoryController::class, 'delCategory']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        /* 字段管理 */
        Route::group('/field', function () {
            Route::get('/list', [\app\admin\controller\sys_manage\FieldController::class, 'fieldList']);
            Route::get('/selectList', [\app\admin\controller\sys_manage\FieldController::class, 'selectList']);
            Route::get('/info/{id:\d+}', [\app\admin\controller\sys_manage\FieldController::class, 'fieldInfo']);
            Route::post('/add', [\app\admin\controller\sys_manage\FieldController::class, 'addField']);
            Route::post('/update/{id:\d+}', [\app\admin\controller\sys_manage\FieldController::class, 'updateFields']);
            Route::post('/updateStatus/{id:\d+}', [\app\admin\controller\sys_manage\FieldController::class, 'updateStatus']);
            Route::delete('/delete', [\app\admin\controller\sys_manage\FieldController::class, 'delField']);
        });
        /* 配置管理 */
        Route::group('/config', function () {
            Route::get('/list', [\app\admin\controller\sys_manage\ConfigController::class, 'configList']);
            Route::get('/info/{id:\d+}', [\app\admin\controller\sys_manage\ConfigController::class, 'configInfo']);
            Route::post('/add', [\app\admin\controller\sys_manage\ConfigController::class, 'addConfig']);
            Route::post('/update/{id:\d+}', [\app\admin\controller\sys_manage\ConfigController::class, 'updateConfig']);
            Route::post('/updateStatus/{id:\d+}', [\app\admin\controller\sys_manage\ConfigController::class, 'updateStatus']);
            Route::delete('/delete', [\app\admin\controller\sys_manage\ConfigController::class, 'delConfig']);
//
//            // 底部菜单
//            Route::get('/bottomMenuList', [\app\admin\controller\sys_manage\ConfigController::class, 'bottomMenuList']);
//            Route::post('/bottomMenuSave', [\app\admin\controller\sys_manage\ConfigController::class, 'bottomMenuSave']);
//            // 导航菜单
//            Route::get('/navMenuList', [\app\admin\controller\sys_manage\ConfigController::class, 'navMenuList']);
//            Route::post('/navMenuSave', [\app\admin\controller\sys_manage\ConfigController::class, 'navMenuSave']);

            // 参数配置
            Route::get('/paramsList', [\app\admin\controller\sys_manage\ConfigController::class, 'paramsList']);
            Route::post('/paramsSave', [\app\admin\controller\sys_manage\ConfigController::class, 'paramsSave']);

        });
        /* 运费模板管理 */
        Route::group('/postageTemplate', function () {
            Route::get('/list', [\app\admin\controller\sys_manage\PostageTemplateController::class, 'select']);
            Route::post('/add', [\app\admin\controller\sys_manage\PostageTemplateController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\sys_manage\PostageTemplateController::class, 'update']);
            Route::post('/updateStatus', [\app\admin\controller\sys_manage\PostageTemplateController::class, 'updateStatus']);
            Route::delete('/delete', [\app\admin\controller\sys_manage\PostageTemplateController::class, 'delete']);
        });
        Route::group('/adv', function () {
            Route::get('/list', [\app\admin\controller\sys_manage\AdvController::class, 'select']);
            Route::post('/add', [\app\admin\controller\sys_manage\AdvController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\sys_manage\AdvController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\sys_manage\AdvController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        Route::group('/protocol', function () {
            Route::get('/list', [\app\admin\controller\sys_manage\ProtocolController::class, 'select']);
            Route::post('/add', [\app\admin\controller\sys_manage\ProtocolController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\sys_manage\ProtocolController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\sys_manage\ProtocolController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        Route::group('/healthyClassroom', function () {
            Route::get('/list', [\app\admin\controller\sys_manage\HealthyClassroomController::class, 'select']);
            Route::post('/add', [\app\admin\controller\sys_manage\HealthyClassroomController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\sys_manage\HealthyClassroomController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\sys_manage\HealthyClassroomController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        Route::group('/finance', function () {
            Route::get('/info', [\app\admin\controller\sys_manage\FinanceController::class, 'info']);
            Route::post('/update', [\app\admin\controller\sys_manage\FinanceController::class, 'update']);
        });
        Route::group('/banner', function () {
            Route::get('/list', [\app\admin\controller\sys_manage\BannerController::class, 'select']);
            Route::post('/add', [\app\admin\controller\sys_manage\BannerController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\sys_manage\BannerController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\sys_manage\BannerController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        Route::group('/article', function () {
            Route::get('/list', [\app\admin\controller\sys_manage\ArticleController::class, 'select']);
            Route::post('/add', [\app\admin\controller\sys_manage\ArticleController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\sys_manage\ArticleController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\sys_manage\ArticleController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        Route::group('/news', function () {
            Route::get('/list', [\app\admin\controller\sys_manage\NewsController::class, 'select']);
            Route::post('/add', [\app\admin\controller\sys_manage\NewsController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\sys_manage\NewsController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\sys_manage\NewsController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        Route::group('/question', function () {
            Route::get('/list', [\app\admin\controller\sys_manage\QuestionController::class, 'select']);
            Route::post('/add', [\app\admin\controller\sys_manage\QuestionController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\sys_manage\QuestionController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\sys_manage\QuestionController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        Route::group('/menu', function () {
            Route::get('/my', [\app\admin\controller\sys_manage\MenuController::class, 'myMenu']);
            Route::get('/list', [\app\admin\controller\sys_manage\MenuController::class, 'select']);
            Route::post('/save', [\app\admin\controller\sys_manage\MenuController::class, 'save']);
            Route::post('/add', [\app\admin\controller\sys_manage\MenuController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\sys_manage\MenuController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\sys_manage\MenuController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        /* 供应商管理 */
        Route::group('/supplier', function () {
            Route::get('/list', [\app\admin\controller\sys_manage\SupplierController::class, 'select']);
            Route::post('/add', [\app\admin\controller\sys_manage\SupplierController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\sys_manage\SupplierController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\sys_manage\SupplierController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        /* 日志管理 */
        Route::group('/log', function () {
            Route::get('/list', [\app\admin\controller\sys_manage\LogsController::class, 'select']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        /* 工单管理 */
        Route::group('/task', function () {
            Route::get('/list', [\app\admin\controller\sys_manage\TaskController::class, 'select']);
            Route::get('/info', [\app\admin\controller\sys_manage\TaskController::class, 'info']);
            Route::post('/update', [\app\admin\controller\sys_manage\TaskController::class, 'update']);
            Route::post('/process', [\app\admin\controller\sys_manage\TaskController::class, 'process']);
            Route::get('/processLog', [\app\admin\controller\sys_manage\TaskController::class, 'processLog']);
            Route::delete('/delete', [\app\admin\controller\sys_manage\TaskController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
    });

    /* 业务支撑 */
    Route::group('/life', function () {
        /* 演职人员管理 */
        Route::group('/cinemaPerformers', function () {
            Route::get('/list', [\app\admin\controller\life\CinemaPerformersController::class, 'select']);
            Route::post('/add', [\app\admin\controller\life\CinemaPerformersController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\life\CinemaPerformersController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\life\CinemaPerformersController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        /* 影片类型管理 */
        Route::group('/cinemaIlk', function () {
            Route::get('/list', [\app\admin\controller\life\CinemaIlkController::class, 'select']);
            Route::post('/add', [\app\admin\controller\life\CinemaIlkController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\life\CinemaIlkController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\life\CinemaIlkController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        /* 影片管理 */
        Route::group('/cinema', function () {
            Route::get('/list', [\app\admin\controller\life\CinemaController::class, 'select']);
            Route::post('/add', [\app\admin\controller\life\CinemaController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\life\CinemaController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\life\CinemaController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        /* 教师管理 */
        Route::group('/teacher', function () {
            Route::get('/list', [\app\admin\controller\life\CollegeTeacherController::class, 'select']);
            Route::post('/add', [\app\admin\controller\life\CollegeTeacherController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\life\CollegeTeacherController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\life\CollegeTeacherController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        /* 课程管理 */
        Route::group('/courses', function () {
            Route::get('/list', [\app\admin\controller\life\CollegeCoursesController::class, 'select']);
            Route::post('/add', [\app\admin\controller\life\CollegeCoursesController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\life\CollegeCoursesController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\life\CollegeCoursesController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        /* 课程安排管理 */
        Route::group('/teaching', function () {
            Route::get('/list', [\app\admin\controller\life\CollegeTeachingController::class, 'select']);
            Route::post('/add', [\app\admin\controller\life\CollegeTeachingController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\life\CollegeTeachingController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\life\CollegeTeachingController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        /* 地块管理 */
        Route::group('/farmLand', function () {
            Route::get('/list', [\app\admin\controller\life\FarmLandController::class, 'select']);
            Route::get('/info', [\app\admin\controller\life\FarmLandController::class, 'info']);
            Route::post('/add', [\app\admin\controller\life\FarmLandController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\life\FarmLandController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\life\FarmLandController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        /* 农场商品管理 */
        Route::group('/farmGoods', function () {
//            Route::get('/list', [\app\admin\controller\life\FarmGoodsController::class, 'select']);
            Route::post('/add', [\app\admin\controller\life\FarmGoodsController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\life\FarmGoodsController::class, 'update']);
//            Route::post('/updateStatus', [\app\admin\controller\life\FarmGoodsController::class, 'updateStatus']);
//            Route::delete('/delete', [\app\admin\controller\life\FarmGoodsController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        /* 农场套餐管理 */
        Route::group('/farmPackage', function () {
            Route::get('/list', [\app\admin\controller\life\FarmPackageController::class, 'select']);
            Route::post('/add', [\app\admin\controller\life\FarmPackageController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\life\FarmPackageController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\life\FarmPackageController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        /* 农场套餐商品管理 */
        Route::group('/farmPackageGoods', function () {
            Route::get('/list', [\app\admin\controller\life\FarmPackageGoodsController::class, 'select']);
            Route::post('/add', [\app\admin\controller\life\FarmPackageGoodsController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\life\FarmPackageGoodsController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\life\FarmPackageGoodsController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        /* 健康美食管理 */
        Route::group('/healthyFood', function () {
            Route::get('/list', [\app\admin\controller\life\HealthyFoodController::class, 'select']);
            Route::post('/add', [\app\admin\controller\life\HealthyFoodController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\life\HealthyFoodController::class, 'update']);
            Route::post('/updateStatus', [\app\admin\controller\life\HealthyFoodController::class, 'updateStatus']);
            Route::delete('/delete', [\app\admin\controller\life\HealthyFoodController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        /* 康旅路线管理 */
        Route::group('/travelLine', function () {
            Route::get('/list', [\app\admin\controller\life\TravelLineController::class, 'select']);
            Route::post('/add', [\app\admin\controller\life\TravelLineController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\life\TravelLineController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\life\TravelLineController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        /* 康旅排期管理 */
        Route::group('/travelScheduling', function () {
            Route::get('/list', [\app\admin\controller\life\TravelSchedulingController::class, 'select']);
            Route::post('/add', [\app\admin\controller\life\TravelSchedulingController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\life\TravelSchedulingController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\life\TravelSchedulingController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
    });
    /* 医疗 */
    Route::group('/medical', function () {
        /* 医生管理 */
        Route::group('/doctor', function () {
            Route::get('/list', [\app\admin\controller\medical\DoctorController::class, 'select']);
            Route::post('/add', [\app\admin\controller\medical\DoctorController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\medical\DoctorController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\medical\DoctorController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        /* 店铺管理 */
        Route::group('/shop', function () {
            Route::get('/select', [\app\admin\controller\medical\ShopController::class, 'selectList']);
            Route::get('/list', [\app\admin\controller\medical\ShopController::class, 'select']);
            Route::post('/add', [\app\admin\controller\medical\ShopController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\medical\ShopController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\medical\ShopController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        /* 可预约的服务管理 */
        Route::group('/reservationService', function () {
            Route::get('/list', [\app\admin\controller\medical\ReservationServiceController::class, 'select']);
            Route::post('/add', [\app\admin\controller\medical\ReservationServiceController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\medical\ReservationServiceController::class, 'update']);
            Route::post('/updateStatus', [\app\admin\controller\medical\ReservationServiceController::class, 'updateStatus']);
            Route::delete('/delete', [\app\admin\controller\medical\ReservationServiceController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        /* 可预约的科室管理 */
        Route::group('/dept', function () {
            Route::get('/list', [\app\admin\controller\medical\DeptController::class, 'select']);
            Route::post('/add', [\app\admin\controller\medical\DeptController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\medical\DeptController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\medical\DeptController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        /* 预约业务员管理 */
        Route::group('/salesman', function () {
            Route::get('/list', [\app\admin\controller\medical\SalesmanController::class, 'select']);
            Route::post('/add', [\app\admin\controller\medical\SalesmanController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\medical\SalesmanController::class, 'update']);
            Route::post('/updateStatus', [\app\admin\controller\medical\SalesmanController::class, 'updateStatus']);
            Route::delete('/delete', [\app\admin\controller\medical\SalesmanController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        /* 医疗团队管理 */
        Route::group('/team', function () {
            Route::get('/list', [\app\admin\controller\medical\TeamController::class, 'deptList']);
            Route::get('/info/{id:\d+}', [\app\admin\controller\medical\TeamController::class, 'deptInfo']);
            Route::post('/add', [\app\admin\controller\medical\TeamController::class, 'addDept']);
            Route::post('/update/{id:\d+}', [\app\admin\controller\medical\TeamController::class, 'updateDept']);
            Route::post('/updateStatus/{id:\d+}', [\app\admin\controller\medical\TeamController::class, 'updateStatus']);
            Route::delete('/delete', [\app\admin\controller\medical\TeamController::class, 'delDept']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
    });
    /* 服务团队管理 */
    Route::group('/serviceTeam', function () {
        Route::get('/list', [\app\admin\controller\ServiceTeamController::class, 'deptList']);
        Route::get('/info/{id:\d+}', [\app\admin\controller\ServiceTeamController::class, 'deptInfo']);
        Route::post('/add', [\app\admin\controller\ServiceTeamController::class, 'addDept']);
        Route::post('/update/{id:\d+}', [\app\admin\controller\ServiceTeamController::class, 'updateDept']);
        Route::post('/updateStatus/{id:\d+}', [\app\admin\controller\ServiceTeamController::class, 'updateStatus']);
        Route::delete('/delete', [\app\admin\controller\ServiceTeamController::class, 'delDept']);
    })->middleware([
        \app\middleware\AdminAuthCheck::class
    ]);
    /* 健康 */
    Route::group('/healthy', function () {
        /* 健康产品管理管理 */
        Route::group('/product', function () {
            Route::get('/list', [\app\admin\controller\healthy\ProductController::class, 'select']);
            Route::post('/add', [\app\admin\controller\healthy\ProductController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\healthy\ProductController::class, 'update']);
            Route::post('/updateStatus', [\app\admin\controller\healthy\ProductController::class, 'updateStatus']);
            Route::delete('/delete', [\app\admin\controller\healthy\ProductController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
    });
    /* 居家 */
    Route::group('/atHome', function () {
        /* 商品管理 */
        Route::group('/goods', function () {
            Route::get('/list', [\app\admin\controller\at_home\GoodsController::class, 'select']);
            Route::post('/add', [\app\admin\controller\at_home\GoodsController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\at_home\GoodsController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\at_home\GoodsController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
    });
    /* 资产管理 */
    Route::group('/asset', function () {
        /* 户型管理 */
        Route::group('/houseType', function () {
            Route::get('/list', [\app\admin\controller\asset\HouseTypeController::class, 'select']);
            Route::post('/add', [\app\admin\controller\asset\HouseTypeController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\asset\HouseTypeController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\asset\HouseTypeController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
    });
    Route::group('/customer', function () {
        Route::get('/list', [\app\admin\controller\customer\IndexController::class, 'select']);
        Route::post('/add', [\app\admin\controller\customer\IndexController::class, 'insert']);
        Route::post('/update', [\app\admin\controller\customer\IndexController::class, 'update']);
        Route::delete('/delete', [\app\admin\controller\customer\IndexController::class, 'delete']);
        Route::post('/conversion', [\app\admin\controller\customer\IndexController::class, 'conversion']);
    });
    /* 用户管理 */
    Route::group('/member', function () {
        /* 家庭管理 */
        Route::group('/family', function () {
            Route::get('/list', [\app\admin\controller\member\FamilyController::class, 'list']);
            Route::get('/list/{id:\w+}', [\app\admin\controller\member\FamilyController::class, 'selectList']);
            Route::get('/info/{id:\w+}', [\app\admin\controller\member\FamilyController::class, 'selectInfo']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        Route::group('/account', function () {
            Route::get('/my/{id:\w+}', [\app\admin\controller\member\AccountController::class, 'my']);
            Route::post('/incomeExpend', [\app\admin\controller\member\AccountController::class, 'incomeExpend']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        // 用户管理
        Route::group('', function () {
            Route::get('/selectList', [\app\admin\controller\member\MemberController::class, 'selectList']);
            Route::get('/selectFamilyMemberList', [\app\admin\controller\member\MemberController::class, 'selectFamilyMemberList']);
            Route::get('/list', [\app\admin\controller\member\MemberController::class, 'list']);
            Route::post('/add', [\app\admin\controller\member\MemberController::class, 'add']);
            Route::post('/update', [\app\admin\controller\member\MemberController::class, 'update']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        // 业主管理
        Route::group('/owner', function () {
            Route::get('/selectList', [\app\admin\controller\member\OwnerController::class, 'selectList']);
            Route::get('/list', [\app\admin\controller\member\OwnerController::class, 'list']);
            Route::post('/add', [\app\admin\controller\member\OwnerController::class, 'add']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        /* 核销管理 */
        Route::group('/benefit', function () {
            Route::get('/list', [\app\admin\controller\member\BenefitController::class, 'select']);
            Route::get('/my/{id:[0-9a-zA-Z]+}', [\app\admin\controller\member\BenefitController::class, 'my']);
            Route::post('/add', [\app\admin\controller\member\BenefitController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\member\BenefitController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\member\BenefitController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        /* 档案管理 */
        Route::group('/wellnessRecord', function () {
            Route::get('/my/{id:[0-9a-zA-Z]+}', [\app\admin\controller\member\WellnessRecordController::class, 'my']);
            Route::get('/advice/{id:[0-9a-zA-Z]+}', [\app\admin\controller\member\WellnessRecordController::class, 'advice']);
            Route::get('/archives/{id:[0-9a-zA-Z]+}', [\app\admin\controller\member\WellnessRecordController::class, 'archives']);
            Route::get('/checkup/{id:[0-9a-zA-Z]+}', [\app\admin\controller\member\WellnessRecordController::class, 'checkup']);
            Route::get('/visit/{id:[0-9a-zA-Z]+}', [\app\admin\controller\member\WellnessRecordController::class, 'visit']);
            Route::get('/list', [\app\admin\controller\member\WellnessRecordController::class, 'select']);
            Route::get('/info', [\app\admin\controller\member\WellnessRecordController::class, 'info']);
            Route::post('/add', [\app\admin\controller\member\WellnessRecordController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\member\WellnessRecordController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\member\WellnessRecordController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        /* 体检管理 */
        Route::group('/checkup', function () {
            Route::get('/list', [\app\admin\controller\member\CheckupController::class, 'select']);
            Route::post('/add', [\app\admin\controller\member\CheckupController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\member\CheckupController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\member\CheckupController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        /* 来访管理 */
        Route::group('/visiting', function () {
            Route::get('/list', [\app\admin\controller\member\VisitingController::class, 'select']);
            Route::post('/add', [\app\admin\controller\member\VisitingController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\member\VisitingController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\member\VisitingController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        /* 设备管理 */
        Route::group('/device', function () {
            Route::get('/{id:[0-9a-zA-Z]+}', [\app\admin\controller\member\MemberController::class, 'device']);
            Route::post('/add', [\app\admin\controller\member\MemberController::class, 'addDevice']);
            Route::post('/update', [\app\admin\controller\member\MemberController::class, 'updateDevice']);
            Route::delete('/delete', [\app\admin\controller\member\MemberController::class, 'deleteDevice']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        /* 等级计价规则 */
        Route::group('/rulePricing', function () {
            Route::get('/selectList', [\app\admin\controller\member\RulePricingController::class, 'selectList']);
            Route::get('/list', [\app\admin\controller\member\RulePricingController::class, 'select']);
            Route::post('/add', [\app\admin\controller\member\RulePricingController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\member\RulePricingController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\member\RulePricingController::class, 'delete']);
        });
        /* 等级 */
        Route::group('/role', function () {
            Route::get('/list', [\app\admin\controller\member\RoleController::class, 'select']);
            Route::post('/add', [\app\admin\controller\member\RoleController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\member\RoleController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\member\RoleController::class, 'delete']);
        });
    });
    /* 营销管理 */
    Route::group('/marketing', function () {
        /* 营业场所管理（独立表） */
        Route::group('/premises', function () {
            Route::get('/list', [\app\admin\controller\marketing\PremisesController::class, 'select']);
            Route::post('/add', [\app\admin\controller\marketing\PremisesController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\marketing\PremisesController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\marketing\PremisesController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        /* 营业场所管理（部门表） */
        Route::group('/deptPremises', function () {
            Route::get('/list', [\app\admin\controller\marketing\DeptPremisesController::class, 'select']);
            Route::get('/info', [\app\admin\controller\marketing\DeptPremisesController::class, 'info']);
            Route::post('/add', [\app\admin\controller\marketing\DeptPremisesController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\marketing\DeptPremisesController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\marketing\DeptPremisesController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        /* 营销团队管理 */
        Route::group('/team', function () {
            Route::get('/list', [\app\admin\controller\marketing\TeamController::class, 'deptList']);
            Route::get('/info/{id:\d+}', [\app\admin\controller\marketing\TeamController::class, 'deptInfo']);
            Route::post('/add', [\app\admin\controller\marketing\TeamController::class, 'addDept']);
            Route::post('/update/{id:\d+}', [\app\admin\controller\marketing\TeamController::class, 'updateDept']);
            Route::post('/updateStatus/{id:\d+}', [\app\admin\controller\marketing\TeamController::class, 'updateStatus']);
            Route::delete('/delete', [\app\admin\controller\marketing\TeamController::class, 'delDept']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
    });
    /* 康养设备管理 */
    Route::group('/device', function () {
        Route::group('/ledger', function () {
            Route::get('/list', [\app\admin\controller\device\LedgerController::class, 'select']);
            Route::get('/select', [\app\admin\controller\device\LedgerController::class, 'selectList']);
            Route::post('/add', [\app\admin\controller\device\LedgerController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\device\LedgerController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\device\LedgerController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        Route::group('', function () {
            Route::get('/list', [\app\admin\controller\device\DeviceController::class, 'select']);
            Route::get('/select', [\app\admin\controller\device\DeviceController::class, 'selectList']);
            Route::post('/add', [\app\admin\controller\device\DeviceController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\device\DeviceController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\device\DeviceController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        Route::group('/meta', function () {
            Route::get('/list', [\app\admin\controller\device\MetadataController::class, 'select']);
            Route::get('/select', [\app\admin\controller\device\MetadataController::class, 'selectList']);
            Route::post('/add', [\app\admin\controller\device\MetadataController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\device\MetadataController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\device\MetadataController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
    });
    /* 优惠券管理 */
    Route::group('/coupon', function () {
        Route::group('', function () {
            Route::get('/list', [\app\admin\controller\coupon\CouponController::class, 'select']);
            Route::post('/add', [\app\admin\controller\coupon\CouponController::class, 'insert']);
            Route::post('/update', [\app\admin\controller\coupon\CouponController::class, 'update']);
            Route::delete('/delete', [\app\admin\controller\coupon\CouponController::class, 'delete']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
    });
    /* 订单管理 */
    Route::group('/order', function () {
        // 全部订单
        Route::group('/whole', function () {
            Route::get('/list', [\app\admin\controller\order\WholeController::class, 'select']);
            Route::get('/sheet', [\app\admin\controller\order\WholeController::class, 'sheet']);
            Route::get('/update', [\app\admin\controller\order\WholeController::class, 'update']);
            Route::post('/delivery', [\app\admin\controller\order\WholeController::class, 'delivery']);
            Route::get('/myOrder', [\app\admin\controller\order\WholeController::class, 'myOrder']);

        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        // 全部订单
        Route::group('/pending', function () {
            Route::get('/list', [\app\admin\controller\order\PendingController::class, 'select']);
            Route::get('/sheet', [\app\admin\controller\order\PendingController::class, 'sheet']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        // 售后订单
        Route::group('/return', function () {
            Route::get('/list', [\app\admin\controller\order\ReturnController::class, 'select']);
            Route::get('/sheet', [\app\admin\controller\order\ReturnController::class, 'sheet']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        // 已完成订单
        Route::group('/complete', function () {
            Route::get('/list', [\app\admin\controller\order\CompleteController::class, 'select']);
            Route::get('/sheet', [\app\admin\controller\order\CompleteController::class, 'sheet']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        // 预约订单
        Route::group('/appointment', function () {
            Route::get('/list', [\app\admin\controller\order\AppointmentController::class, 'select']);
            Route::get('/add', [\app\admin\controller\order\AppointmentController::class, 'add']);
            Route::get('/update', [\app\admin\controller\order\AppointmentController::class, 'update']);
            Route::post('/confirm/{id:[0-9a-zA-Z]+}', [\app\admin\controller\order\AppointmentController::class, 'confirm']);
            Route::get('/getTimes', [\app\admin\controller\order\AppointmentController::class, 'getTimes']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        // 退款管理
        Route::group('/refund', function () {
            Route::get('/list', [\app\admin\controller\order\RefundController::class, 'select']);
            Route::get('/sheet', [\app\admin\controller\order\RefundController::class, 'sheet']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
    });
    /* 统计 */
    Route::group('/statistics', function () {
        Route::get('/member', [\app\admin\controller\statistics\MemberController::class, 'index']);
    })->middleware([
        \app\middleware\AdminAuthCheck::class
    ]);
    /* 客户端相关数据 */
    Route::group('/client', function () {
        Route::group('', function () {
            // 我的关注
            Route::get('/favorite/list', [\app\admin\controller\client\FavoriteController::class, 'select']);
            // 我的收藏
            Route::get('/collection/list', [\app\admin\controller\client\CollectionController::class, 'select']);
            // 我的积分
            Route::get('/points/list', [\app\admin\controller\client\PointsController::class, 'select']);
            // 我的评价
            Route::get('/evaluate/list', [\app\admin\controller\client\EvaluateController::class, 'select']);
            // 我的购物车
            Route::get('/cart/list', [\app\admin\controller\client\CartController::class, 'select']);
            // 我的优惠券
            Route::get('/coupon/list', [\app\admin\controller\client\CouponController::class, 'select']);
            // 我的浏览数据
            Route::get('/browse/list', [\app\admin\controller\client\BrowseController::class, 'select']);
        })->middleware([
            \app\middleware\AdminAuthCheck::class
        ]);
        /* 消息管理 */
        Route::group('/message', function () {
            Route::group('', function () {
                Route::get('/list', [\app\admin\controller\client\MessageController::class, 'select']);
                Route::post('/add', [\app\admin\controller\client\MessageController::class, 'insert']);
                Route::post('/update', [\app\admin\controller\client\MessageController::class, 'update']);
                Route::delete('/delete', [\app\admin\controller\client\MessageController::class, 'delete']);
            })->middleware([
                \app\middleware\AdminAuthCheck::class
            ]);
        });
        /* APP参数管理 */
        Route::group('/appParams', function () {
            Route::group('', function () {
                Route::get('/list', [\app\admin\controller\client\AppParamsController::class, 'select']);
                Route::post('/add', [\app\admin\controller\client\AppParamsController::class, 'insert']);
                Route::post('/update', [\app\admin\controller\client\AppParamsController::class, 'update']);
                Route::delete('/delete', [\app\admin\controller\client\AppParamsController::class, 'delete']);
            })->middleware([
                \app\middleware\AdminAuthCheck::class
            ]);
        });
    });

    Route::group('/dashboard', function () {
        Route::get('/', [\app\admin\controller\dashboard\DashboardController::class, 'index']);
    });
});
